autowisp.database.data_model.hdf5_datasets module — AutoWISP documentation

# autowisp.database.data_model.hdf5_datasets module

## Class Inheritance Diagram

Define the hdf5_datasets table.

class autowisp.database.data_model.hdf5_datasets.HDF5DataSet(**kwargs)

  Bases: `DataModelBase`

  The table describing how to include datasets in HDF5 files.

  __str__()

    Human readable description.

  abspath

    The full absolute path to the dataset within the HDF5 file.

  compression

    If not NULL, which compression filter to use when creating the dataset.

  compression_options

    Any options to pass to the compression filter. For gzip, this is passed as int(compression_options).

  description

    A brief description of what this attribute tracks.

  dtype

    The data type to use for this dataset. See h5py for possible values and their meanings.

  hdf5_structure_version_id

    Which structure version of which pipeline product is this element configuration for.

  id

    A unique identifier for each row.

  pipeline_key

    How is this dataset referred to by the pipeline.

  replace_nonfinite

    For numeric datasets, if this is not NULL, any non-finite values are replaced by this value.

  scaleoffset

    If not null, enable the scale/offset filter for this dataset with the specified precision.

  shuffle

    Should the shuffle filter be enabled?

  structure_version
  timestamp

    When record was last changed